@@ -146,13 +146,6 @@ class VB():
         else:
             plot_nodes = [self[x] for x in plot]
 
-        # Make certain that at least one of the nodes in the model has been
-        # observed
-        if (not self.ignore_bound_checks
-            and all(~np.any(n.observed) for n in self.model)):
-
-            raise Exception("At least one node in the model must be observed.")
-
         converged = False
 
         if tqdm is not None:
